==> kmyfirewall_0.9.6.2.orig.tar.gz: kmyfirewall-0.9.6.2/kmyfirewall/core/kmfcheckinput.h <==
/***************************************************************************
                       kmfcheckinput.h  -  description
                          -------------------
 begin                : Tue Aug 6 2002
 copyright            : (C) 2002 by Christian Hubinger
 email                : a9806056@unet.univie.ac.at
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KMFCHECKINPUT_H
#define KMFCHECKINPUT_H


/**
  *@author Christian Hubinger
  */

#include <qdict.h>

class QString;
class KMFError;
class KMFCheckInput {
public:
	KMFCheckInput();
	~KMFCheckInput();

	KMFError* checkInput( QString& inp, const QString& inp_type );

private:    // functions
	void generateMsgDict();
	bool checkIP( QString input );
	bool checkFQHN( QString inp );
	bool checkChainName( QString inp );
	bool checkRuleName( QString inp );
	bool checkMAC( QString inp );
	bool checkNetMask ( QString inp );
	bool checkNetWork ( QString inp );
	bool checkPORT( QString inp );
	bool checkPORTRANGE( QString inp );
	bool checkMULTIPORT( QString inp );
private:     // data
	QDict<QString> m_msg_dict;
};

#endif

==> kmyfirewall_1.0.orig.tar.gz: kmyfirewall-1.0/kmyfirewall/core/kmfcheckinput.h <==
/***************************************************************************
 begin                : Tue Aug 6 2002
 copyright            : (C) 2002 by Christian Hubinger
 email                : chubinger@gmail.com
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KMFCHECKINPUT_H
#define KMFCHECKINPUT_H


/**
  *@author Christian Hubinger
  */

#include <qdict.h>

#include <kdemacros.h>

class QString;
class KMFError;
class KDE_EXPORT KMFCheckInput {
public:
	KMFCheckInput();
	~KMFCheckInput();

	/** Check the given input string is it matches the criterias
		for the given input type */
	void checkInput( QString& inp, const QString& inp_type, KMFError* );

private:    // functions
	void generateMsgDict();
	
	/** Check if inp is a IP address */
	bool checkIP( QString input );
	
	/** Check if inp is a FQHN */
	bool checkFQHN( QString inp );
	
	/** Check if inp can be a chain name */
	bool checkChainName( QString inp );
	
	/** Check if inp can be a rule name */
	bool checkRuleName( QString inp );
	
	/** Check if inp is a MAC address */
	bool checkMAC( QString inp );
	
	/** Check if inp is a net mask */
	bool checkNetMask ( QString inp );
	
	/** Check if inp is a network */
	bool checkNetWork ( QString inp );
	
	/** Check if inp is a port */
	bool checkPORT( QString inp );
	
	/** Check if inp is a portrange */
	bool checkPORTRANGE( QString inp );
	
	/** Check if inp is a multiport string */
	bool checkMULTIPORT( QString inp );
private:     // data
	QDict<QString> m_msg_dict;
};

#endif
